@@ -1,5 +1,6 @@
 from .authentication import Authenticate
 from .state import env
 from .resource import Resource
+from .account import Account
 
-__all__ = ['Authenticate', 'env', 'Resource']
+__all__ = ['Authenticate', 'env', 'Resource', 'Account']
