@@ -3,11 +3,14 @@ from mock import patch
 
 from httplib2 import Response
 from libthirty import Authenticate
+from libthirty.state import env
 
 
 @patch('httplib2.Http.request')
 def test_a_valid_authentication(mock_request):
     """Create a successfull authentication object."""
+    if env.has_key('auth'):
+        del(env['auth'])
     response = Response({'status': 200})
     mock_request.return_value = (response, '')
     auth = Authenticate('testuser', 'testpassword', '30loops',
@@ -19,8 +22,11 @@ def test_a_valid_authentication(mock_request):
     # Make sure the the request has been really made
     assert mock_request.called
 
+
 @patch('httplib2.Http.request')
 def test_an_invalid_authentication(mock_request):
+    if env.has_key('auth'):
+        del(env['auth'])
     response = Response({'status': 403})
     mock_request.return_value = (response, '')
     auth = Authenticate('testuser', 'testpassword', '30loops',
@@ -28,5 +34,3 @@ def test_an_invalid_authentication(mock_request):
     assert auth.is_authenticated == False
     # Make sure the the request has been really made
     assert mock_request.called
-    
-
